@@ -74,36 +74,36 @@ function form_save() {
 }
 
 function api_networks_remove($network_id){
-	db_execute_prepared('DELETE FROM automation_networks 
-		WHERE id = ?', 
+	db_execute_prepared('DELETE FROM automation_networks
+		WHERE id = ?',
 		array($network_id));
 
-	db_execute_prepared('DELETE FROM automation_devices 
-		WHERE network_id = ?', 
+	db_execute_prepared('DELETE FROM automation_devices
+		WHERE network_id = ?',
 		array($network_id));
 }
 
 function api_networks_enable($network_id){
-	db_execute_prepared('UPDATE automation_networks 
-		SET enabled="on" 
-		WHERE id = ?', 
+	db_execute_prepared('UPDATE automation_networks
+		SET enabled="on"
+		WHERE id = ?',
 		array($network_id));
 }
 
 function api_networks_disable($network_id){
-	db_execute_prepared('UPDATE automation_networks 
-		SET enabled="" 
-		WHERE id = ?', 
+	db_execute_prepared('UPDATE automation_networks
+		SET enabled=""
+		WHERE id = ?',
 		array($network_id));
 }
 
 function api_networks_cancel($network_id){
-	db_execute_prepared('UPDATE IGNORE automation_processes 
-		SET command="cancel" 
-		WHERE task="tmaster" 
-		AND network_id = ?', 
+	db_execute_prepared('UPDATE IGNORE automation_processes
+		SET command="cancel"
+		WHERE task="tmaster"
+		AND network_id = ?',
 		array($network_id));
-} 
+}
 
 function api_networks_discover($network_id) {
 	global $config;
@@ -117,15 +117,15 @@ function api_networks_discover($network_id) {
 		if (!$running) {
 			if ($config['poller_id'] == $poller_id) {
 				exec_background(read_config_option('path_php_binary'), '-q ' . read_config_option('path_webroot') . "/poller_automation.php --network=$network_id --force");
-			}else{
+			} else {
 				$hostname = db_fetch_cell_prepared('SELECT hostname FROM poller WHERE id = ?', array($poller_id));
 				$response = file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=discover&network=' . $network_id);
 			}
-		}else{
+		} else {
 			$_SESSION['automation_message'] = "Can Not Restart Discovery for Discovery in Progress for Network '$name'";
 			raise_message('automation_message');
 		}
-	}else{
+	} else {
 		$_SESSION['automation_message'] = "Can Not Perform Discovery for Disabled Network '$name'";
 		raise_message('automation_message');
 	}
@@ -138,6 +138,7 @@ function api_networks_save($post) {
 		/* general information */
 		$save['name']          = form_input_validate($post['name'], 'name', '', false, 3);
 		$save['poller_id']     = form_input_validate($post['poller_id'], 'poller_id', '^[0-9]+$', false, 3);
+		$save['site_id']       = form_input_validate($post['site_id'], 'site_id', '^[0-9]+$', false, 3);
 		$save['subnet_range']  = form_input_validate($post['subnet_range'], 'subnet_range', '', false, 3);
 		$save['dns_servers']   = form_input_validate($post['dns_servers'], 'dns_servers', '', true, 3);
 
@@ -184,13 +185,13 @@ function api_networks_save($post) {
 				$_SESSION['automation_message'] = __('ERROR: You must specificy the day of the week.  Disabling Network %s!.', $net);
 				raise_message('automation_message');
 			}
-		}elseif ($save['sched_type'] == '4') {
+		} elseif ($save['sched_type'] == '4') {
 			if ($save['month'] == '' || $save['day_of_month'] == '') {
 				$save['enabled'] = '';
 				$_SESSION['automation_message'] = __('ERROR: You must specificy both the Months and Days of Month.  Disabling Network %s!.', $net);
 				raise_message('automation_message');
 			}
-		}elseif ($save['sched_type'] == '5') {
+		} elseif ($save['sched_type'] == '5') {
 			if ($save['month'] == '' || $save['monthly_day'] == '' || $save['monthly_week'] == '') {
 				$save['enabled'] = '';
 				$_SESSION['automation_message'] = __('ERROR: You must specificy the Months, Weeks of Months, and Days of Week.  Disabling Network %s!.', $net);
@@ -209,7 +210,7 @@ function api_networks_save($post) {
 			$ips = automation_calculate_total_ips($networks, $i);
 			if ($ips !== false) {
 				$total_ips += $ips;
-			}else{
+			} else {
 				$continue = false;
 				$_SESSION['automation_message'] = __("ERROR: Network '%s' is Invalid.", $net);
 				raise_message('automation_message');
@@ -225,10 +226,10 @@ function api_networks_save($post) {
 			$network_id = 0;
 			if (!is_error_message()) {
 				$network_id = sql_save($save, 'automation_networks');
-	
+
 				if ($network_id) {
 					raise_message(1);
-				}else{
+				} else {
 					raise_message(2);
 				}
 			}
@@ -257,19 +258,19 @@ function form_actions() {
 				foreach($selected_items as $item) {
 					api_networks_remove($item);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '3') { /* enable */
+			} elseif (get_nfilter_request_var('drp_action') == '3') { /* enable */
 				foreach($selected_items as $item) {
 					api_networks_enable($item);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '2') { /* disable */
+			} elseif (get_nfilter_request_var('drp_action') == '2') { /* disable */
 				foreach($selected_items as $item) {
 					api_networks_disable($item);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '4') { /* run now */
+			} elseif (get_nfilter_request_var('drp_action') == '4') { /* run now */
 				foreach($selected_items as $item) {
 					api_networks_discover($item);
 				}
-			}elseif (get_nfilter_request_var('drp_action') == '5') { /* cancel */
+			} elseif (get_nfilter_request_var('drp_action') == '5') { /* cancel */
 				foreach($selected_items as $item) {
 					api_networks_cancel($item);
 				}
@@ -285,7 +286,7 @@ function form_actions() {
 	$networks_list = ''; $i = 0;
 
 	/* loop through each of the device types selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -312,28 +313,28 @@ function form_actions() {
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
 		</tr>\n";
-	}elseif (get_nfilter_request_var('drp_action') == '3') { /* enable */
+	} elseif (get_nfilter_request_var('drp_action') == '3') { /* enable */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to enable the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
 		</tr>\n";
-	}elseif (get_nfilter_request_var('drp_action') == '2') { /* disable */
+	} elseif (get_nfilter_request_var('drp_action') == '2') { /* disable */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to disable the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
 		</tr>\n";
-	}elseif (get_nfilter_request_var('drp_action') == '4') { /* discover now */
+	} elseif (get_nfilter_request_var('drp_action') == '4') { /* discover now */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to discover the following Network(s).') . "</p>
 				<div class='itemlist'><ul>$networks_list</ul></div>
 			</td>
 		</tr>\n";
-	}elseif (get_nfilter_request_var('drp_action') == '5') { /* cancel discovery now */
+	} elseif (get_nfilter_request_var('drp_action') == '5') { /* cancel discovery now */
 		print "<tr>
 			<td class='textArea'>
 				<p>" . __('Click \'Continue\' to cancel on going Network Discovery(s).') . "</p>
@@ -345,17 +346,17 @@ function form_actions() {
 	if (!isset($networks_array)) {
 		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one Network.') . "</span></td></tr>\n";
 		$save_html = '';
-	}else{
-		$save_html = "<input type='submit' value='" . __('Continue') . "' name='save'>";
+	} else {
+		$save_html = "<input type='submit' value='" . __esc('Continue') . "' name='save'>";
 	}
 
 	print "<tr>
 		<td colspan='2' class='saveRow'>
 			<input type='hidden' name='action' value='actions'>
 			<input type='hidden' name='selected_items' value='" . (isset($networks_array) ? serialize($networks_array) : '') . "'>
-			<input type='hidden' name='drp_action' value='" . get_nfilter_request_var('drp_action') . "'>" . (strlen($save_html) ? "
-			<input type='submit' name='cancel' value='" . __('Cancel') . "'>
-			$save_html" : "<input type='submit' name='cancel' value='" . __('Return') . "'>") . "
+			<input type='hidden' name='drp_action' value='" . get_nfilter_request_var('drp_action') . "'>" . ($save_html != '' ? "
+			<input type='submit' name='cancel' value='" . __esc('Cancel') . "'>
+			$save_html" : "<input type='submit' name='cancel' value='" . __esc('Return') . "'>") . "
 		</td>
 	</tr>\n";
 
@@ -374,16 +375,16 @@ function network_edit() {
 	/* ==================================================== */
 
 	$sched_types = array(
-		'1' => __('Manual'), 
-		'2' => __('Daily'), 
-		'3' => __('Weekly'), 
-		'4' => __('Monthly'), 
+		'1' => __('Manual'),
+		'2' => __('Daily'),
+		'3' => __('Weekly'),
+		'4' => __('Monthly'),
 		'5' => __('Monthly on Day'));
 
 	if (!isempty_request_var('id')) {
 		$network = db_fetch_row_prepared('SELECT * FROM automation_networks WHERE id = ?', array(get_request_var('id')));
 		$header_label = __('Network Discovery Range [edit: %s]', htmlspecialchars($network['name']));
-	}else{
+	} else {
 		$header_label = __('Network Discovery Range [new]');
 	}
 
@@ -392,6 +393,7 @@ function network_edit() {
 	'spacer0' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('General Settings'),
+		'collapsible' => 'true'
 		),
 	'name' => array(
 		'method' => 'textbox',
@@ -409,14 +411,23 @@ function network_edit() {
 		'default' => read_config_option('default_poller'),
 		'sql' => 'SELECT id, name FROM poller ORDER BY name',
 		),
+	'site_id' => array(
+		'method' => 'drop_sql',
+		'friendly_name' => __('Associated Site'),
+		'description' => __('Choose the Cacti Site that you wish to associate discovered Devices with.'),
+		'value' => '|arg1:site_id|',
+		'default' => read_config_option('default_site'),
+		'sql' => 'SELECT id, name FROM sites ORDER BY name',
+		'none_value' => __('None')
+		),
 	'subnet_range' => array(
 		'method' => 'textarea',
 		'friendly_name' => __('Subnet Range'),
 		'description' => __('Enter valid Network Ranges separated by commas.  You may use an IP address, a Network range such as 192.168.1.0/24 or 192.168.1.0/255.255.255.0, or using wildcards such as 192.168.*.*'),
 		'value' => '|arg1:subnet_range|',
-		'textarea_rows' => '2',
-		'textarea_cols' => '60',
-		'max_length' => '255',
+		'textarea_rows' => '4',
+		'textarea_cols' => '80',
+		'max_length' => '1024',
 		'placeholder' => '192.168.1.0/24'
 		),
 	'total_ips' => array(
@@ -447,15 +458,15 @@ function network_edit() {
 		'description' => __('Define the number of threads to use for discovering this Network Range.'),
 		'value' => '|arg1:threads|',
 		'array' => array(
-			'1'  => __('%d Thread', 1), 
-			'2'  => __('%d Threads', 2), 
-			'3'  => __('%d Threads', 3), 
-			'4'  => __('%d Threads', 4), 
-			'5'  => __('%d Threads', 5), 
-			'6'  => __('%d Threads', 6), 
-			'7'  => __('%d Threads', 7), 
-			'8'  => __('%d Threads', 8), 
-			'9'  => __('%d Threads', 9), 
+			'1'  => __('%d Thread', 1),
+			'2'  => __('%d Threads', 2),
+			'3'  => __('%d Threads', 3),
+			'4'  => __('%d Threads', 4),
+			'5'  => __('%d Threads', 5),
+			'6'  => __('%d Threads', 6),
+			'7'  => __('%d Threads', 7),
+			'8'  => __('%d Threads', 8),
+			'9'  => __('%d Threads', 9),
 			'10' => __('%d Threads', 10),
 			'20' => __('%d Threads', 20),
 			'50' => __('%d Threads', 50)
@@ -468,15 +479,15 @@ function network_edit() {
 		'description' => __('After the selected Run Limit, the discovery process will be terminated.'),
 		'value' => '|arg1:run_limit|',
 		'array' => array(
-			'60'    => __('%d Minute', 1), 
-			'300'   => __('%d Minutes', 5), 
-			'600'   => __('%d Minutes', 10), 
-			'1200'  => __('%d Minutes', 20), 
-			'1800'  => __('%d Minutes', 30), 
-			'3600'  => __('%d Hour', 1), 
-			'7200'  => __('%d Hours', 2), 
-			'14400' => __('%d Hours', 4), 
-			'28800' => __('%d Hours', 8), 
+			'60'    => __('%d Minute', 1),
+			'300'   => __('%d Minutes', 5),
+			'600'   => __('%d Minutes', 10),
+			'1200'  => __('%d Minutes', 20),
+			'1800'  => __('%d Minutes', 30),
+			'3600'  => __('%d Hour', 1),
+			'7200'  => __('%d Hours', 2),
+			'14400' => __('%d Hours', 4),
+			'28800' => __('%d Hours', 8),
 			),
 		'default' => 1200
 		),
@@ -508,6 +519,7 @@ function network_edit() {
 	'spacer2' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('Discovery Timing'),
+		'collapsible' => 'true'
 		),
 	'start_at' => array(
 		'method' => 'textbox',
@@ -525,12 +537,12 @@ function network_edit() {
 		'value' => '|arg1:recur_every|',
 		'default' => '1',
 		'array' => array(
-			1 => '1', 
-			2 => '2', 
-			3 => '3', 
-			4 => '4', 
-			5 => '5', 
-			6 => '6', 
+			1 => '1',
+			2 => '2',
+			3 => '3',
+			4 => '4',
+			5 => '5',
+			6 => '6',
 			7 => '7'
 			),
 		),
@@ -539,12 +551,12 @@ function network_edit() {
 		'friendly_name' => __('Days of Week'),
 		'description' => __('What Day(s) of the week will this Network Range be discovered.'),
 		'array' => array(
-			1 => __('Sunday'), 
-			2 => __('Monday'), 
-			3 => __('Tuesday'), 
-			4 => __('Wednesday'), 
-			5 => __('Thursday'), 
-			6 => __('Friday'), 
+			1 => __('Sunday'),
+			2 => __('Monday'),
+			3 => __('Tuesday'),
+			4 => __('Wednesday'),
+			5 => __('Thursday'),
+			6 => __('Friday'),
 			7 => __('Saturday')
 			),
 		'value' => '|arg1:day_of_week|',
@@ -555,17 +567,17 @@ function network_edit() {
 		'friendly_name' => __('Months of Year'),
 		'description' => __('What Months(s) of the Year will this Network Range be discovered.'),
 		'array' => array(
-			1 => __('January'), 
-			2 => __('February'), 
-			3 => __('March'), 
-			4 => __('April'), 
-			5 => __('May'), 
-			6 => __('June'), 
-			7 => __('July'), 
-			8 => __('August'), 
-			9 => __('September'), 
-			10 => __('October'), 
-			11 => __('November'), 
+			1 => __('January'),
+			2 => __('February'),
+			3 => __('March'),
+			4 => __('April'),
+			5 => __('May'),
+			6 => __('June'),
+			7 => __('July'),
+			8 => __('August'),
+			9 => __('September'),
+			10 => __('October'),
+			11 => __('November'),
 			12 => __('December')
 			),
 		'value' => '|arg1:month|',
@@ -584,9 +596,9 @@ function network_edit() {
 		'friendly_name' => __('Week(s) of Month'),
 		'description' => __('What Week(s) of the Month will this Network Range be discovered.'),
 		'array' => array(
-			1 => __('First'), 
-			2 => __('Second'), 
-			3 => __('Third'), 
+			1 => __('First'),
+			2 => __('Second'),
+			3 => __('Third'),
 			'32' => __('Last')
 			),
 		'value' => '|arg1:monthly_week|',
@@ -597,12 +609,12 @@ function network_edit() {
 		'friendly_name' => __('Day(s) of Week'),
 		'description' => __('What Day(s) of the week will this Network Range be discovered.'),
 		'array' => array(
-			1 => __('Sunday'), 
-			2 => __('Monday'), 
-			3 => __('Tuesday'), 
-			4 => __('Wednesday'), 
-			5 => __('Thursday'), 
-			6 => __('Friday'), 
+			1 => __('Sunday'),
+			2 => __('Monday'),
+			3 => __('Tuesday'),
+			4 => __('Wednesday'),
+			5 => __('Thursday'),
+			6 => __('Friday'),
 			7 => __('Saturday')
 			),
 		'value' => '|arg1:monthly_day|',
@@ -611,6 +623,7 @@ function network_edit() {
 	'spacer1' => array(
 		'method' => 'spacer',
 		'friendly_name' => __('Reachability Settings'),
+		'collapsible' => 'true'
 		),
 	'snmp_id' => array(
 		'method' => 'drop_sql',
@@ -667,7 +680,7 @@ function network_edit() {
 
 	form_start('automation_networks.php', 'form_network');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	draw_edit_form(
 		array(
@@ -676,7 +689,7 @@ function network_edit() {
 		)
 	);
 
-	html_end_box();
+	html_end_box(true, true);
 
 	form_hidden_box('save_component_network', '1', '');
 	form_hidden_box('id', !isempty_request_var('id') ? get_request_var('id'):0, 0);
@@ -686,54 +699,54 @@ function network_edit() {
 	?>
 	<script type='text/javascript'>
 	$(function() {
-		$('#day_of_week').multiselect({ 
-			selectedList: 7, 
+		$('#day_of_week').multiselect({
+			selectedList: 7,
 			noneSelectedText: '<?php print __('Select the days(s) of the week');?>',
-			header: false, 
-			height: 54, 
-			multipleRow: true, 
-			multipleRowWidth: 90, 
-			minWidth: 450 
+			header: false,
+			height: 54,
+			multipleRow: true,
+			multipleRowWidth: 90,
+			minWidth: 450
 		});
 
-		$('#month').multiselect({ 
-			selectedList: 7, 
+		$('#month').multiselect({
+			selectedList: 7,
 			noneSelectedText: '<?php print __('Select the month(s) of the year');?>',
-			header: false, 
-			height: 82, 
-			multipleRow: true, 
-			multipleRowWidth: 90, 
-			minWidth: 400 
+			header: false,
+			height: 82,
+			multipleRow: true,
+			multipleRowWidth: 90,
+			minWidth: 400
 		});
 
-		$('#day_of_month').multiselect({ 
-			selectedList: 15, 
+		$('#day_of_month').multiselect({
+			selectedList: 15,
 			noneSelectedText: '<?php print __('Select the day(s) of the month');?>',
-			header: false, 
-			height: 162, 
-			multipleRow: true, 
-			multipleRowWidth: 55, 
-			minWidth: 400 
+			header: false,
+			height: 162,
+			multipleRow: true,
+			multipleRowWidth: 55,
+			minWidth: 400
 		});
 
-		$('#monthly_week').multiselect({ 
-			selectedList: 4, 
+		$('#monthly_week').multiselect({
+			selectedList: 4,
 			noneSelectedText: '<?php print __('Select the week(s) of the month');?>',
-			header: false, 
+			header: false,
 			height: 28,
 			multipleRow: true,
 			multipleRowWidth: 70,
 			minWidth: 300
 		});
 
-		$('#monthly_day').multiselect({ 
-			selectedList: 7, 
+		$('#monthly_day').multiselect({
+			selectedList: 7,
 			noneSelectedText: '<?php print __('Select the day(s) of the week');?>',
-			header: false, 
-			height: 54, 
-			multipleRow: true, 
-			multipleRowWidth: 90, 
-			minWidth: 450 
+			header: false,
+			height: 54,
+			multipleRow: true,
+			multipleRowWidth: 90,
+			minWidth: 450
 		});
 
 		$('#start_at').datetimepicker({
@@ -859,7 +872,7 @@ function get_networks(&$sql_where, $rows, $apply_limits = TRUE) {
 
 	if ($apply_limits) {
 		$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
-	}else{
+	} else {
 		$sql_limit = '';
 	}
 
@@ -880,28 +893,28 @@ function networks() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'name', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			)
 	);
@@ -911,9 +924,9 @@ function networks() {
 
 	if (get_request_var('rows') == -1) {
 		$rows = read_config_option('num_rows_table');
-	}elseif (get_request_var('rows') == -2) {
+	} elseif (get_request_var('rows') == -2) {
 		$rows = 99999999;
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -936,10 +949,10 @@ function networks() {
 	html_start_box('', '100%', '', '3', 'center', '');
 
 	$sched_types = array(
-		'1' => __('Manual'), 
-		'2' => __('Daily'), 
-		'3' => __('Weekly'), 
-		'4' => __('Monthly'), 
+		'1' => __('Manual'),
+		'2' => __('Daily'),
+		'3' => __('Weekly'),
+		'4' => __('Monthly'),
 		'5' => __('Monthly on Day')
 	);
 
@@ -967,11 +980,11 @@ function networks() {
 				$progress = "0/0/0";
 				$status   = array();
 				$updown['up'] = $updown['snmp'] = '0';
-			}else{
+			} else {
 				$running = db_fetch_cell_prepared('SELECT COUNT(*) FROM automation_processes WHERE network_id = ?', array($network['id']));
 
 				if ($running > 0) {
-					$status = db_fetch_row_prepared('SELECT 
+					$status = db_fetch_row_prepared('SELECT
 						COUNT(*) AS total,
 						SUM(CASE WHEN status=0 THEN 1 ELSE 0 END) AS pending,
 						SUM(CASE WHEN status=1 THEN 1 ELSE 0 END) AS running,
@@ -983,7 +996,7 @@ function networks() {
 
 					if (empty($status['total'])) {
 						$progress = "0/0/0";
-					}else{
+					} else {
 						$progress = $status['pending'] . '/' . $status['running'] . '/' . $status['done'];
 					}
 
@@ -995,7 +1008,7 @@ function networks() {
 						$updown['up']   = 0;
 						$updown['snmp'] = 0;
 					}
-				}else{
+				} else {
 					$updown['up']   = $network['up_hosts'];
 					$updown['snmp'] = $network['snmp_hosts'];
 
@@ -1019,7 +1032,7 @@ function networks() {
 			form_checkbox_cell($network['name'], $network['id']);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr><td colspan='10'><em>" . __('No Networks Found') . "</em></td></tr>";
 	}
 	html_end_box(false);
@@ -1048,7 +1061,7 @@ function networks_filter() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' id='filter' size='25' value='<?php print get_request_var('filter');?>'>
+						<input type='text' id='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Networks');?>
@@ -1058,28 +1071,26 @@ function networks_filter() {
 							<option value='-1'<?php if (get_request_var('rows') == '-1') {?> selected<?php }?>><?php print __('Default');?></option>
 							<?php
 							if (sizeof($item_rows)) {
-							foreach ($item_rows as $key => $value) {
-								print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
-							}
+								foreach ($item_rows as $key => $value) {
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . $value . "</option>\n";
+								}
 							}
 							?>
 						</select>
 					</td>
 					<td>
-						<input type='button' id='go' title='<?php print __('Search');?>' value='<?php print __('Go');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' title='<?php print __('Clear Filtered');?>' value='<?php print __('Clear');?>'>
+						<span>
+							<input type='button' id='go' title='<?php print __esc('Search');?>' value='<?php print __esc('Go');?>'>
+							<input type='button' id='clear' title='<?php print __esc('Clear Filtered');?>' value='<?php print __esc('Clear');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' value='<?php print get_request_var('page');?>'>
 			</form>
 			<script type='text/javascript'>
 			function applyFilter() {
 				strURL  = '?rows=' + $('#rows').val();
 				strURL += '&filter=' + $('#filter').val();
-				strURL += '&page=' + $('#page').val();
 				strURL += '&header=false';
 
 				loadPageNoHeader(strURL);
