@@ -123,8 +123,15 @@ $fields_profile_rra_edit = array(
 		'default' => '600'
 		),
 	'timespan' => array(
+		'method' => 'drop_array',
+		'friendly_name' => __('Default Timespan'),
+		'description' => __('When viewing a Graph based upon the RRA in question, the default Timespan to show for that Graph.'),
+		'value' => '|arg1:timespan|',
+		'array' => $timespans
+		),
+	'retention' => array(
 		'method' => 'other',
-		'friendly_name' => __('Effective Retention'),
+		'friendly_name' => __('Data Retention'),
 		'description' => __('Based upon the Aggregation Level, the Rows, and the Polling Interval the amount of data that will be retained in the RRA'),
 		'value' => ''
 		),
@@ -391,6 +398,7 @@ $struct_data_source = array(
 		'method' => 'drop_sql',
 		'description' => __('Select the Data Source Profile.  The Data Source Profile controls polling interval, the data aggregation, and retention policy for the resulting Data Sources.'),
 		'sql' => 'SELECT id, name FROM data_source_profiles ORDER BY name',
+		'default' => db_fetch_cell('SELECT id FROM data_source_profiles ORDER BY `default` DESC LIMIT 1'),
 		'none_value' => __('External'),
 		'flags' => ''
 		),
